<template>
    <!-- Selección de Recogida Local (Siempre Visible) -->
    <label class="label-shipping-method">
        <input v-model="selectedShippingMethod" type="radio" value="local_pickup" @change="validateForm" />
        <div class="title-shipping-method">Retiro personalmente en <span>JUSTICIALISTAS</span></div>
        <div class="subtitle-shipping-method">Jose Antonio Guardado 50, Córdoba</div>
    </label>
    <!-- Selección de Recogida Local (Siempre Visible) -->

    <!-- Opciones de Envío adicionales (mantiene los radios visibles tras Calcular) -->
    <div class="block-shipping-oca">
        <!-- Retiro en Sucursal -->
        <label class="label-shipping-oca">
            <input
                v-model="selectedShippingMethod"
                type="radio"
                value="branch_pickup"
                :disabled="!store.isShippingCalculated"
                @change="validateForm"
            />
            <div class="title-shipping-oca">Retiro en Sucursal</div>
        </label>
        <select
            v-if="selectedShippingMethod === 'branch_pickup'"
            v-model="selectedBranch"
            class="form-select select-shipping-oca"
            @change="validateForm"
        >
            <option v-for="branch in store.branches" :key="branch.IdCentroImposicion" :value="branch">
                {{ branch.Sucursal }}<span> ({{ branch.Calle }} {{ branch.Numero }})</span>
            </option>
        </select>

        <!-- Envío a Domicilio -->
        <label class="label-shipping-oca">
            <input
                v-model="selectedShippingMethod"
                type="radio"
                value="home_delivery"
                :disabled="!store.isShippingCalculated"
                @change="validateForm"
            />
            <div class="title-shipping-oca">Envío a Domicilio Particular</div>
        </label>
    </div>

    <!-- Formulario para calcular costo del envio -->
    <div v-if="showCalculationForm" class="block-calculate-shipping">
        <div>Calcular envío</div>
        <form>
            <div class="form-group">
                <input v-model="postalCode" type="text" placeholder="Código postal" class="form-control" />
            </div>
            <a class="btn-mtop mini-button-success" @click="handleCalculateShipping()">Calcular</a>
        </form>
    </div>
    <div class="mt10">
        <a v-if="!showCalculationForm" class="btn-mtop mini-button-success" @click="toggleCalculationForm"
            >Modificar Datos de Envío</a
        >
    </div>

    <!-- Formulario para calcular costo del envio -->
</template>

<script setup>
import { ref, watch, onMounted, defineProps, defineEmits } from "vue";
import { cartStore } from "../../../js/stores/cart.js";
import { useShippingStore } from "../../../js/stores/shippingStore.js";

const props = defineProps({
    showAddressForm: {
        type: Boolean,
        default: true,
    },
});

const showOcaOptions = ref(false);
const showCalculationForm = ref(false);
const store = cartStore();
const shippingStore = useShippingStore();
const selectedShippingMethod = ref(store.selectedShippingMethod);
const selectedBranch = ref(store.selectedBranch);
const selectedProvince = ref(store.selectedProvince);
const selectedCity = ref(store.selectedCity);
const postalCode = ref(store.selectedPostalCode);
const branches = ref(store.branches);
const emit = defineEmits(["validate"]);
// const isShippingCalculated = ref(store.isShippingCalculated);

const handleCalculateShipping = async () => {
    if (!store.selectedPostalCode) {
        alert("Por favor complete el Código Postal.");
        return;
    }

    if (store.items.length < 1) {
        store.updateDoorToDoorCost(0);
        store.updateDoorToBranchCost(0);
        store.updateShippingCost(0);
        store.updateBranches([]);
        alert("El carrito está vacio");
        return;
    }

    await shippingStore.calculateShipping(); // Llamas al método del store
    showOcaOptions.value = true;
    showCalculationForm.value = false;
    store.updateShippingCalculated(true);
};

const toggleCalculationForm = () => {
    showCalculationForm.value = !showCalculationForm.value;
};

const validateForm = () => {
    let isValid = true;

    if (selectedShippingMethod.value === "branch_pickup" && !selectedBranch.value) {
        isValid = false;
    }

    emit("validate", isValid);
};

watch([selectedShippingMethod, selectedBranch], validateForm);
watch(selectedShippingMethod, (value) => store.updateShippingMethod(value));
watch(selectedBranch, (value) => store.updateBranch(value));
watch(selectedProvince, (value) => store.updateProvince(value));
watch(selectedCity, (value) => store.updateCity(value));
watch(postalCode, (value) => store.updatePostalCode(value));
watch(branches, (value) => store.updateBranches(value));

onMounted(() => {
    validateForm();

    if (postalCode.value === null || postalCode.value === "") {
        showOcaOptions.value = false;
        showCalculationForm.value = true;
    } else {
        showOcaOptions.value = true;
        showCalculationForm.value = false;
    }
});
</script>

<style scoped>
.accordion-item {
    border: none;
}

.label-shipping-method {
    display: ruby;

    .title-shipping-method {
        margin-left: 18px;

        span {
            font-weight: 700;
            text-transform: uppercase;
        }
    }

    .subtitle-shipping-method {
        margin-left: 30px;
    }
}

.block-shipping-oca {
    display: grid;

    .label-shipping-oca {
        display: ruby;
        margin-top: 10px;

        .title-shipping-oca {
            margin-left: 18px;
        }
    }
}

.block-calculate-shipping {
    margin-top: 12px;

    .form-select {
        margin-bottom: 10px;
    }
}

.select-shipping-oca {
    margin-left: 29px;
}
</style>
